@@ -33,7 +33,6 @@ from math import pi
 import os
 
 import cairo
-from gettext import gettext as _
 import gi
 gi.require_version('MediaArt', '2.0')
 from gi.repository import (Gdk, GdkPixbuf, Gio, GLib, GObject, Gtk, MediaArt,
@@ -139,11 +138,11 @@ def _make_icon_frame(pixbuf, art_size=None, scale=1):
 
 class ArtSize(Enum):
     """Enum for icon sizes"""
-    xsmall = (34, 34)
-    small = (48, 48)
-    medium = (128, 128)
-    large = (256, 256)
-    xlarge = (512, 512)
+    XSMALL = (34, 34)
+    SMALL = (48, 48)
+    MEDIUM = (128, 128)
+    LARGE = (256, 256)
+    XLARGE = (512, 512)
 
     def __init__(self, width, height):
         """Intialize width and height"""
@@ -166,7 +165,8 @@ class DefaultIcon(GObject.GObject):
 
     @log
     def __init__(self, scale=1):
-        GObject.GObject.__init__(self)
+        super().__init__()
+
         self._scale = scale
 
     @log
@@ -237,7 +237,8 @@ class AlbumArtCache(GObject.GObject):
 
     @log
     def __init__(self, scale=1):
-        GObject.GObject.__init__(self)
+        super().__init__()
+
         self._scale = scale
 
         self.cache_dir = os.path.join(GLib.get_user_cache_dir(), 'media-art')
@@ -427,7 +428,7 @@ class AlbumArtCache(GObject.GObject):
 
         success, cache_path = MediaArt.get_path(artist, album, "album")
         if not success:
-            self._lookup_remote(item, callback, itr, art_size)
+            self._lookup_remote(item, art_size, callback, itr)
 
         self._discoverer_items[item.get_url()] = [item, art_size, callback,
                                                   itr, cache_path]
