@@ -101,7 +101,8 @@ class Player(GObject.GObject):
 
     @log
     def __init__(self, parent_window):
-        GObject.GObject.__init__(self)
+        super().__init__()
+
         self._parent_window = parent_window
         self.playlist = None
         self.playlistType = None
@@ -113,7 +114,7 @@ class Player(GObject.GObject):
         self.cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
             DefaultIcon.Type.loading,
-            ArtSize.xsmall)
+            ArtSize.XSMALL)
         self._missingPluginMessages = []
 
         Gst.init(None)
@@ -604,7 +605,7 @@ class Player(GObject.GObject):
         self._currentArtist = artist
 
         self.coverImg.set_from_surface(self._loading_icon_surface)
-        self.cache.lookup(media, ArtSize.xsmall, self._on_cache_lookup, None)
+        self.cache.lookup(media, ArtSize.XSMALL, self._on_cache_lookup, None)
 
         self._currentTitle = utils.get_media_title(media)
         self.titleLabel.set_label(self._currentTitle)
@@ -802,8 +803,8 @@ class Player(GObject.GObject):
         self.titleLabel = self._ui.get_object('title')
         self.artistLabel = self._ui.get_object('artist')
         self.coverImg = self._ui.get_object('cover')
-        self.coverImg.set_property("width-request", ArtSize.xsmall.width)
-        self.coverImg.set_property("height-request", ArtSize.xsmall.height)
+        self.coverImg.set_property("width-request", ArtSize.XSMALL.width)
+        self.coverImg.set_property("height-request", ArtSize.XSMALL.height)
 
         self.duration = self._ui.get_object('duration')
         self.repeatBtnImage = self._ui.get_object('playlistRepeat')
@@ -894,7 +895,7 @@ class Player(GObject.GObject):
         timing from the user, for updating the songPlaybackTimeLabel.
         """
         # Don't run until progressScale has been realized
-        if self.progressScale.get_realized() == False:
+        if self.progressScale.get_realized() is False:
             return
 
         # Update self.timeout
@@ -1158,13 +1159,10 @@ class MissingCodecsDialog(Gtk.MessageDialog):
 
     @log
     def __init__(self, parent_window, install_helper_name):
-        Gtk.MessageDialog.__init__(self,
-                                   transient_for=parent_window,
-                                   modal=True,
-                                   destroy_with_parent=True,
-                                   message_type=Gtk.MessageType.ERROR,
-                                   buttons=Gtk.ButtonsType.CANCEL,
-                                   text=_("Unable to play the file"))
+        super().__init__(
+            transient_for=parent_window, modal=True, destroy_with_parent=True,
+            message_type=Gtk.MessageType.ERROR, buttons=Gtk.ButtonsType.CANCEL,
+            text=_("Unable to play the file"))
 
         # TRANSLATORS: this is a button to launch a codec installer.
         # %s will be replaced with the software installer's name, e.g.
