@@ -32,7 +32,6 @@ from gnomemusic.grilo import grilo
 from gnomemusic.query import Query
 from gettext import gettext as _
 import inspect
-import time
 sparql_dateTime_format = "%Y-%m-%dT%H:%M:%SZ"
 
 from gnomemusic import log
@@ -107,10 +106,20 @@ class StaticPlaylists:
 
 
 class Playlists(GObject.GObject):
+
     __gsignals__ = {
-        'playlist-created': (GObject.SignalFlags.RUN_FIRST, None, (Grl.Media,)),
-        'playlist-deleted': (GObject.SignalFlags.RUN_FIRST, None, (Grl.Media,)),
-        'playlist-updated': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+        'playlist-created': (
+            GObject.SignalFlags.RUN_FIRST, None, (Grl.Media,)
+        ),
+        'playlist-deleted': (
+            GObject.SignalFlags.RUN_FIRST, None, (Grl.Media,)
+        ),
+        'playlist-updated': (
+            GObject.SignalFlags.RUN_FIRST, None, (int,)
+        ),
+        'playlist-renamed': (
+            GObject.SignalFlags.RUN_FIRST, None, (Grl.Media,)
+        ),
         'song-added-to-playlist': (
             GObject.SignalFlags.RUN_FIRST, None, (Grl.Media, Grl.Media)
         ),
@@ -118,6 +127,7 @@ class Playlists(GObject.GObject):
             GObject.SignalFlags.RUN_FIRST, None, (Grl.Media, Grl.Media)
         ),
     }
+
     instance = None
     tracker = None
 
@@ -134,7 +144,8 @@ class Playlists(GObject.GObject):
 
     @log
     def __init__(self):
-        GObject.GObject.__init__(self)
+        super().__init__()
+
         self.tracker = TrackerWrapper().tracker
         self._static_playlists = StaticPlaylists()
 
@@ -142,7 +153,8 @@ class Playlists(GObject.GObject):
 
     @log
     def _on_grilo_ready(self, data=None):
-        """For all static playlists: get ID, if exists; if not, create the playlist and get ID."""
+        """For all static playlists: get ID, if exists; if not, create
+        the playlist and get ID."""
 
         def playlist_id_fetched_cb(cursor, res, playlist):
             """ Called after the playlist id is fetched """
@@ -215,20 +227,22 @@ class Playlists(GObject.GObject):
             """ Called when the static playlist is created """
             data = obj.update_blank_finish(res)
             playlist_urn = data.get_child_value(0).get_child_value(0).\
-                           get_child_value(0).get_child_value(1).get_string()
+                get_child_value(0).get_child_value(1).get_string()
 
             query = Query.get_playlist_with_urn(playlist_urn)
 
             # Start fetching the playlist
-            self.tracker.query_async(query, None, playlist_queried_cb, playlist)
+            self.tracker.query_async(
+                query, None, playlist_queried_cb, playlist)
 
         def tag_created_cb(obj, res, playlist):
             """ Called when the tag is created """
             creation_query = Query.create_playlist_with_tag(title, tag_text)
 
             # Start creating the playlist itself
-            self.tracker.update_blank_async(creation_query, GLib.PRIORITY_LOW,
-                                            None, playlist_created_cb, playlist)
+            self.tracker.update_blank_async(
+                creation_query, GLib.PRIORITY_LOW, None, playlist_created_cb,
+                playlist)
 
         # Start the playlist creation by creating the tag
         self.tracker.update_blank_async(Query.create_tag(tag_text),
@@ -237,7 +251,8 @@ class Playlists(GObject.GObject):
 
     @log
     def update_static_playlist(self, playlist):
-        """Given a static playlist (subclass of StaticPlaylists), updates according to its query."""
+        """Given a static playlist (subclass of StaticPlaylists),
+        updates according to its query."""
         # Clear the playlist
         self.clear_playlist(playlist)
 
@@ -304,7 +319,7 @@ class Playlists(GObject.GObject):
 
         def cursor_callback(cursor, res, data):
             try:
-                has_next = cursor.next_finish(res)
+                cursor.next_finish(res)
             except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
@@ -336,6 +351,25 @@ class Playlists(GObject.GObject):
             None, update_callback, None
         )
 
+    @log
+    def rename(self, item, new_name):
+        """Rename a playlist
+
+        :param item: playlist to rename
+        :param new_name: new playlist name
+        :type item: Grl.Media
+        :type new_name: str
+        :return: None
+        :rtype: None
+        """
+        def update_callback(conn, res, data):
+            conn.update_finish(res)
+            self.emit('playlist-renamed', item)
+
+        self.tracker.update_async(
+            Query.rename_playlist(item.get_id(), new_name), GLib.PRIORITY_LOW,
+            None, update_callback, None)
+
     @log
     def delete_playlist(self, item):
         def update_callback(conn, res, data):
