@@ -25,7 +25,6 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gettext import gettext as _
 from gi.repository import GLib, Tracker
 from gnomemusic import log
 import os
@@ -38,6 +37,7 @@ sparql_midnight_dateTime_format = "%Y-%m-%dT00:00:00Z"
 SECONDS_PER_DAY = 86400
 PUNCTUATION_FILTER = " !\\\"#$%&'()*+,-./:;<=>?@[\\\\]^_`{|}~"
 
+
 class Query():
 
     music_folder = None
@@ -73,7 +73,7 @@ class Query():
         :return: The sparql order by statement
         :rtype: str
         """
-        return """tracker:title-order(%(attr)s)""" % { 'attr': attr };
+        return """tracker:title-order(%(attr)s)""" % {'attr': attr};
 
     @staticmethod
     def all_albums():
@@ -208,9 +208,6 @@ class Query():
     {
         %(where_clause)s
         ?song a nmm:MusicPiece ;
-            nmm:musicAlbumDisc ?disc ;
-            nmm:musicAlbum ?album ;
-            nmm:performer ?performer ;
             nie:url ?url .
         OPTIONAL { ?song nao:hasTag ?tag .
                    FILTER (?tag = nao:predefined-tag-favorite) } .
@@ -240,7 +237,7 @@ class Query():
                       || !BOUND(nfo:belongsToContainer(?playlist)) )
             OPTIONAL { ?playlist nao:hasTag ?tag }
         }
-    ORDER BY !BOUND(?tag) LCASE(?title)
+    ORDER BY DESC(tracker:added(?playlist)) !BOUND(?tag) LCASE(?title)
     """.replace('\n', ' ').strip() % {
             'where_clause': where_clause.replace('\n', ' ').strip(),
             'music_dir': Query.MUSIC_URI
@@ -475,6 +472,31 @@ class Query():
         }
         return query
 
+    @staticmethod
+    def rename_playlist(playlist_id, new_name):
+        query = """
+    INSERT OR REPLACE {
+        ?playlist
+            nie:title "%(title)s"
+    }
+    WHERE {
+        ?playlist
+            a nmm:Playlist ;
+            a nfo:MediaList .
+        OPTIONAL {
+            ?playlist
+                nfo:hasMediaFileListEntry ?entry .
+        }
+        FILTER (
+            tracker:id(?playlist) = %(playlist_id)s
+        )
+    }
+    """.replace("\n", " ").strip() % {
+            'title': new_name,
+            'playlist_id': playlist_id
+        }
+        return query
+
     @staticmethod
     def add_song_to_playlist(playlist_id, song_uri):
         query = """
@@ -992,7 +1014,7 @@ class Query():
                 FILTER ( tracker:id(?urn) = "%(media_id)s" )
             }
         """.replace('\n', '').strip() % {
-            'media_id' : media_id
+            'media_id': media_id
         }
 
         return query
