@@ -27,15 +27,12 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-
-from gi.repository import Gtk, GObject
-
 from gettext import gettext as _
-from gnomemusic.searchbar import Searchbar, DropDown
+from gi.repository import GObject, Gtk
 
 from gnomemusic import log
-import logging
-logger = logging.getLogger(__name__)
+from gnomemusic.searchbar import Searchbar, DropDown
+from gnomemusic.utils import View
 
 
 class ToolbarState:
@@ -56,23 +53,27 @@ class Toolbar(GObject.GObject):
 
     @log
     def __init__(self):
-        GObject.GObject.__init__(self)
-        self._stack_switcher = Gtk.StackSwitcher(
-            margin_top=2, margin_bottom=2, can_focus=False, halign="center")
+        super().__init__()
+
+        self._stack_switcher = Gtk.StackSwitcher(can_focus=False,
+                                                 halign="center")
         self._stack_switcher.show()
         self._ui = Gtk.Builder()
         self._ui.add_from_resource('/org/gnome/Music/headerbar.ui')
         self.header_bar = self._ui.get_object('header-bar')
         self._search_button = self._ui.get_object('search-button')
         self.dropdown = DropDown()
-        self.searchbar = Searchbar(self._stack_switcher, self._search_button, self.dropdown)
+        self.searchbar = Searchbar(
+            self._stack_switcher, self._search_button, self.dropdown)
         self.dropdown.initialize_filters(self.searchbar)
         self._select_button = self._ui.get_object('select-button')
         self._cancel_button = self._ui.get_object('done-button')
         self._back_button = self._ui.get_object('back-button')
         self._selection_menu = self._ui.get_object('selection-menu')
-        self._selection_menu_button = self._ui.get_object('selection-menu-button')
-        self._selection_menu_label = self._ui.get_object('selection-menu-button-label')
+        self._selection_menu_button = self._ui.get_object(
+            'selection-menu-button')
+        self._selection_menu_label = self._ui.get_object(
+            'selection-menu-button-label')
         self._selection_menu_button.set_relief(Gtk.ReliefStyle.NONE)
         if Gtk.get_minor_version() >= 11:
             self.header_bar.remove(self._select_button)
@@ -108,43 +109,38 @@ class Toolbar(GObject.GObject):
 
     @log
     def set_selection_mode(self, selectionMode):
-        self._selection_handler = None
         self._selectionMode = selectionMode
         if selectionMode:
             self._select_button.hide()
             self._cancel_button.show()
             self.header_bar.get_style_context().add_class('selection-mode')
-            self._cancel_button.get_style_context().remove_class('selection-mode')
-            view = self._stack_switcher.get_stack().get_visible_child()
-            self._selection_handler = view.view.connect(
-                'view-selection-changed', view._on_view_selection_changed)
+            self._cancel_button.get_style_context().remove_class(
+                'selection-mode')
         else:
             self.header_bar.get_style_context().remove_class('selection-mode')
             self._select_button.set_active(False)
             self._select_button.show()
             self._cancel_button.hide()
-            view = self._stack_switcher.get_stack().get_visible_child()
-            if self._selection_handler:
-                view.view.disconnect(self._selection_handler)
-            self._selection_handler = None
         self.emit('selection-mode-changed')
         self._update()
 
     @log
-    def on_back_button_clicked(self, widget):
+    def on_back_button_clicked(self, widget=None):
         self._window = self.header_bar.get_parent()
         visible_child = self._window.curr_view.get_visible_child()
 
         view = self._stack_switcher.get_stack().get_visible_child()
         view._back_button_clicked(view)
 
-        if not ((self._window.curr_view == self._window.views[4] or
-                 self._window.curr_view == self._window.views[5]) and
-                 visible_child != self._window.curr_view._grid):
+        current_view = self._window.curr_view
+        if not ((current_view == self._window.views[View.SEARCH]
+                 or current_view == self._window.views[View.EMPTY_SEARCH])
+                and visible_child != current_view._grid):
             self.set_state(ToolbarState.MAIN)
         else:
             self._search_button.set_visible(True)
 
+        self.searchbar.reveal(False)
 
     @log
     def set_state(self, state, btn=None):
@@ -160,6 +156,8 @@ class Toolbar(GObject.GObject):
         else:
             self.reset_header_title()
 
-        self._search_button.set_visible(self._state != ToolbarState.SEARCH_VIEW)
-        self._back_button.set_visible(not self._selectionMode and self._state != ToolbarState.MAIN)
+        self._search_button.set_visible(
+            self._state != ToolbarState.SEARCH_VIEW)
+        self._back_button.set_visible(
+            not self._selectionMode and self._state != ToolbarState.MAIN)
         self.header_bar.set_show_close_button(not self._selectionMode)
