@@ -23,7 +23,7 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _
-from gi.repository import GLib, GObject, Gtk
+from gi.repository import GLib, GObject, Gtk, Gdk
 
 from gnomemusic import log
 from gnomemusic.albumartcache import ArtSize
@@ -41,10 +41,10 @@ class AlbumsView(BaseView):
 
     @log
     def __init__(self, window, player):
-        BaseView.__init__(self, 'albums', _("Albums"), window, None)
-        self._albumWidget = AlbumWidget(player, self)
+        super().__init__('albums', _("Albums"), window, None)
+        self._album_widget = AlbumWidget(player, self)
         self.player = player
-        self.add(self._albumWidget)
+        self.add(self._album_widget)
         self.albums_selected = []
         self.all_items = []
         self.items_selected = []
@@ -67,16 +67,11 @@ class AlbumsView(BaseView):
 
     @log
     def _setup_view(self, view_type):
-        self._view = Gtk.FlowBox(homogeneous=True,
-                                hexpand=True,
-                                halign=Gtk.Align.FILL,
-                                valign=Gtk.Align.START,
-                                selection_mode=Gtk.SelectionMode.NONE,
-                                margin=18,
-                                row_spacing=12,
-                                column_spacing=6,
-                                min_children_per_line=1,
-                                max_children_per_line=25)
+        self._view = Gtk.FlowBox(
+            homogeneous=True, hexpand=True, halign=Gtk.Align.FILL,
+            valign=Gtk.Align.START, selection_mode=Gtk.SelectionMode.NONE,
+            margin=18, row_spacing=12, column_spacing=6,
+            min_children_per_line=1, max_children_per_line=25)
 
         self._view.connect('child-activated', self._on_child_activated)
 
@@ -108,13 +103,14 @@ class AlbumsView(BaseView):
         self._escaped_title = title
         self._artist = utils.get_artist_name(item)
 
-        self._albumWidget.update(self._artist, title, item,
-                                 self._header_bar, self._selection_toolbar)
+        self._album_widget.update(
+            self._artist, title, item, self._header_bar,
+            self._selection_toolbar)
 
         self._header_bar.set_state(ToolbarState.CHILD_VIEW)
         self._header_bar.header_bar.set_title(self._escaped_title)
         self._header_bar.header_bar.sub_title = self._artist
-        self.set_visible_child(self._albumWidget)
+        self.set_visible_child(self._album_widget)
 
     @log
     def update_title(self):
@@ -131,7 +127,7 @@ class AlbumsView(BaseView):
         # FIXME: we call into private objects with full knowledge of
         # what is there
         if self._header_bar._state == ToolbarState.CHILD_VIEW:
-            callback(self._albumWidget._disc_listbox.get_selected_items())
+            callback(self._album_widget._disc_listbox.get_selected_items())
         else:
             self.items_selected = []
             self.items_selected_callback = callback
@@ -156,7 +152,8 @@ class AlbumsView(BaseView):
         artist = utils.get_artist_name(item)
         title = utils.get_media_title(item)
 
-        builder = Gtk.Builder.new_from_resource('/org/gnome/Music/AlbumCover.ui')
+        builder = Gtk.Builder.new_from_resource(
+            '/org/gnome/Music/AlbumCover.ui')
 
         child = Gtk.FlowBoxChild()
         child.image = builder.get_object('image')
@@ -173,8 +170,10 @@ class AlbumsView(BaseView):
         # In the case of off-sized icons (eg. provided in the soundfile)
         # keep the size request equal to all other icons to get proper
         # alignment with GtkFlowBox.
-        child.image.set_property("width-request", ArtSize.medium.width)
-        child.image.set_property("height-request", ArtSize.medium.height)
+        child.image.set_property("width-request", ArtSize.MEDIUM.width)
+        child.image.set_property("height-request", ArtSize.MEDIUM.height)
+
+        child.events.add_events(Gdk.EventMask.TOUCH_MASK)
 
         child.events.connect('button-release-event',
                              self._on_album_event_triggered,
@@ -190,7 +189,7 @@ class AlbumsView(BaseView):
         child.add(builder.get_object('main_box'))
         child.show()
 
-        self._cache.lookup(item, ArtSize.medium, self._on_lookup_ready, child)
+        self._cache.lookup(item, ArtSize.MEDIUM, self._on_lookup_ready, child)
 
         return child
 
@@ -206,9 +205,11 @@ class AlbumsView(BaseView):
 
     @log
     def _on_child_toggled(self, check, pspec, child):
-        if check.get_active() and not child.media_item in self.albums_selected:
+        if (check.get_active()
+                and child.media_item not in self.albums_selected):
             self.albums_selected.append(child.media_item)
-        elif not check.get_active() and child.media_item in self.albums_selected:
+        elif (not check.get_active()
+                and child.media_item in self.albums_selected):
             self.albums_selected.remove(child.media_item)
 
         self.update_header_from_selection(len(self.albums_selected))
