@@ -22,6 +22,7 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
+import logging
 from gettext import gettext as _
 from gi.repository import Gd, GLib, Gtk, Pango
 
@@ -31,6 +32,8 @@ from gnomemusic.views.baseview import BaseView
 from gnomemusic.widgets.artistalbumswidget import ArtistAlbumsWidget
 import gnomemusic.utils as utils
 
+logger = logging.getLogger(__name__)
+
 
 class ArtistsView(BaseView):
     """Main view of all available artists
@@ -49,8 +52,8 @@ class ArtistsView(BaseView):
         :param GtkWidget window: The main window
         :param player: The main player object
         """
-        BaseView.__init__(self, 'artists', _("Artists"), window,
-                          Gd.MainViewType.LIST, True)
+        super().__init__(
+            'artists', _("Artists"), window, Gd.MainViewType.LIST, True)
 
         self.player = player
         self._artists = {}
@@ -127,8 +130,8 @@ class ArtistsView(BaseView):
         widget = self._artists[artist.casefold()]['widget']
 
         if widget:
-            artist_widget_model = self.player.running_playlist('Artist',
-                                                                widget.artist)
+            artist_widget_model = self.player.running_playlist(
+                'Artist', widget.artist)
             artist_stack = self._artist_albums_stack
             # FIXME: calling to private model
             if widget._model == artist_widget_model:
@@ -146,9 +149,9 @@ class ArtistsView(BaseView):
                                              hexpand=True)
         self._artist_albums_stack.add(new_artist_albums_widget)
 
-        artist_albums = ArtistAlbumsWidget(artist, albums, self.player,
-                                           self._header_bar,
-                                           self._selection_toolbar, self._window)
+        artist_albums = ArtistAlbumsWidget(
+            artist, albums, self.player, self._header_bar,
+            self._selection_toolbar, self._window)
         self._artists[artist.casefold()]['widget'] = artist_albums
         new_artist_albums_widget.add(artist_albums)
         new_artist_albums_widget.show()
