@@ -54,8 +54,8 @@ class BaseView(Gtk.Stack):
         :param sidebar: The sidebar object (Default: Gtk.Box)
         """
 
-        Gtk.Stack.__init__(self,
-                           transition_type=Gtk.StackTransitionType.CROSSFADE)
+        super().__init__(transition_type=Gtk.StackTransitionType.CROSSFADE)
+
         self._grid = Gtk.Grid(orientation=Gtk.Orientation.HORIZONTAL)
         self._offset = 0
         self.model = Gtk.ListStore(
@@ -96,7 +96,7 @@ class BaseView(Gtk.Stack):
         self._header_bar = window.toolbar
         self._selection_toolbar = window.selection_toolbar
         self._header_bar._select_button.connect(
-           'toggled', self._on_header_bar_toggled)
+            'toggled', self._on_header_bar_toggled)
         self._header_bar._cancel_button.connect(
             'clicked', self._on_cancel_button_clicked)
 
@@ -110,7 +110,7 @@ class BaseView(Gtk.Stack):
         scale = self.get_scale_factor()
         self._cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
-            DefaultIcon.Type.loading, ArtSize.medium)
+            DefaultIcon.Type.loading, ArtSize.MEDIUM)
 
         self._init = False
         grilo.connect('ready', self._on_grilo_ready)
@@ -270,10 +270,10 @@ class BaseView(Gtk.Stack):
     def _set_selection(self, value, parent=None):
         count = 0
         itr = self.model.iter_children(parent)
-        while itr != None:
+        while itr is not None:
             if self.model.iter_has_child(itr):
                 count += self._set_selection(value, itr)
-            if self.model[itr][5] != None:
+            if self.model[itr][5] is not None:
                 self.model[itr][6] = value
                 count += 1
             itr = self.model.iter_next(itr)
@@ -300,5 +300,5 @@ class BaseView(Gtk.Stack):
         select_toolbar._add_to_playlist_button.set_sensitive(False)
         select_toolbar._remove_from_playlist_button.set_sensitive(False)
         self._header_bar._selection_menu_label.set_text(
-             _("Click on items to select them"))
+            _("Click on items to select them"))
         self.queue_draw()
