@@ -22,6 +22,7 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
+import logging
 from gettext import gettext as _
 from gi.repository import Gd, GLib, Gtk, Pango
 
@@ -31,6 +32,8 @@ from gnomemusic.player import DiscoveryStatus
 from gnomemusic.views.baseview import BaseView
 import gnomemusic.utils as utils
 
+logger = logging.getLogger(__name__)
+
 
 class SongsView(BaseView):
     """Main view of all songs sorted artistwise
@@ -49,8 +52,7 @@ class SongsView(BaseView):
         :param GtkWidget window: The main window
         :param player: The main player object
         """
-        BaseView.__init__(self, 'songs', _("Songs"),
-                          window, Gd.MainViewType.LIST)
+        super().__init__('songs', _("Songs"), window, Gd.MainViewType.LIST)
 
         self._offset = 0
         self._iter_to_clean = None
@@ -87,7 +89,7 @@ class SongsView(BaseView):
 
         try:
             itr = self.model.get_iter(path)
-        except ValueError as err :
+        except ValueError as err:
             logger.warn("Error: {}, {}".format(err.__class__, err))
             return
 
