@@ -23,19 +23,14 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _, ngettext
-from gi.repository import Gd, Gdk, GdkPixbuf, GLib, GObject, Gtk, Pango
+from gi.repository import GdkPixbuf, GLib, GObject, Gtk
 
 from gnomemusic import log
 from gnomemusic.albumartcache import AlbumArtCache, DefaultIcon, ArtSize
 from gnomemusic.grilo import grilo
-from gnomemusic.player import DiscoveryStatus
-from gnomemusic.playlists import Playlists
 from gnomemusic.widgets.disclistboxwidget import DiscBox, DiscListBox
 import gnomemusic.utils as utils
 
-NOW_PLAYING_ICON_NAME = 'media-playback-start-symbolic'
-ERROR_ICON_NAME = 'dialog-error-symbolic'
-
 
 class AlbumWidget(Gtk.EventBox):
     """Album widget.
@@ -56,15 +51,15 @@ class AlbumWidget(Gtk.EventBox):
         :param player: The player object
         :param parent_view: The view this widget is part of
         """
-        Gtk.EventBox.__init__(self)
+        super().__init__()
 
-        self._tracks = []
+        self._songs = []
 
         scale = self.get_scale_factor()
         self._cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
             DefaultIcon.Type.loading,
-            ArtSize.large)
+            ArtSize.LARGE)
 
         self._player = player
         self._iter_to_clean = None
@@ -97,7 +92,7 @@ class AlbumWidget(Gtk.EventBox):
         view_box.add(self._disc_listbox)
 
         # FIXME: Assigned to appease searchview
-        # get_selected_tracks
+        # _get_selected_songs
         self.view = self._disc_listbox
 
         self.add(self._builder.get_object('AlbumWidget'))
@@ -140,7 +135,7 @@ class AlbumWidget(Gtk.EventBox):
         :param selection_toolbar: The selection toolbar object
         """
         # reset view
-        self._tracks = []
+        self._songs = []
         self._create_model()
         for widget in self._disc_listbox.get_children():
             self._disc_listbox.remove(widget)
@@ -150,7 +145,7 @@ class AlbumWidget(Gtk.EventBox):
         self._album = album
         self._builder.get_object('cover').set_from_surface(
             self._loading_icon_surface)
-        self._cache.lookup(item, ArtSize.large, self._on_lookup, None)
+        self._cache.lookup(item, ArtSize.LARGE, self._on_lookup, None)
         self._duration = 0
 
         GLib.idle_add(grilo.populate_album_songs, item, self.add_item)
@@ -225,13 +220,13 @@ class AlbumWidget(Gtk.EventBox):
                 self._player.actionbar.set_visible(True)
 
     @log
-    def _create_disc_box(self, disc_nr, disc_tracks):
+    def _create_disc_box(self, disc_nr, disc_songs):
         disc_box = DiscBox(self._model)
-        disc_box.set_tracks(disc_tracks)
+        disc_box.set_songs(disc_songs)
         disc_box.set_disc_number(disc_nr)
         disc_box.set_columns(1)
         disc_box.show_song_numbers(False)
-        disc_box.connect('track-activated', self._track_activated)
+        disc_box.connect('song-activated', self._song_activated)
         disc_box.connect('selection-toggle', self._selection_mode_toggled)
 
         return disc_box
@@ -244,9 +239,8 @@ class AlbumWidget(Gtk.EventBox):
         self._selection_mode = not self._selection_mode
         self._on_selection_mode_request()
 
-
     @log
-    def _track_activated(self, widget, song_widget):
+    def _song_activated(self, widget, song_widget):
         if not song_widget.can_be_played:
             return
 
@@ -255,34 +249,34 @@ class AlbumWidget(Gtk.EventBox):
             return
 
         self._player.stop()
-        self._player.set_playlist('Artist', 'test', song_widget.model,
+        self._player.set_playlist('Album', self._album, song_widget.model,
                                   song_widget.itr, 5, 11)
         self._player.set_playing(True)
         return True
 
     @log
-    def add_item(self, source, prefs, track, remaining, data=None):
+    def add_item(self, source, prefs, song, remaining, data=None):
         """Add a song to the item to album list.
 
         :param source: The grilo source
         :param prefs:
-        :param track: The grilo media object
+        :param song: The grilo media object
         :param remaining: Remaining number of items to add
         :param data: User data
         """
-        if track:
-            self._tracks.append(track)
+        if song:
+            self._songs.append(song)
 
-            self._duration = self._duration + track.get_duration()
+            self._duration = self._duration + song.get_duration()
             return
 
         discs = {}
-        for track in self._tracks:
-            disc_nr = track.get_album_disc_number()
+        for song in self._songs:
+            disc_nr = song.get_album_disc_number()
             if disc_nr not in discs.keys():
-                discs[disc_nr] = [track]
+                discs[disc_nr] = [song]
             else:
-                discs[disc_nr].append(track)
+                discs[disc_nr].append(song)
         for disc_nr in discs:
             disc = self._create_disc_box(disc_nr, discs[disc_nr])
             self._disc_listbox.add(disc)
@@ -327,7 +321,8 @@ class AlbumWidget(Gtk.EventBox):
             song = playlist[_iter][5]
             song_widget = song.song_widget
             self._duration += song.get_duration()
-            escaped_title = GLib.markup_escape_text(utils.get_media_title(song))
+            escaped_title = GLib.markup_escape_text(
+                utils.get_media_title(song))
 
             if (song == current_song):
                 song_widget.now_playing_sign.show()
