@@ -22,13 +22,12 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gettext import gettext as _
-from gi.repository import Gdk, Gio, GLib, GObject, Gtk
+from gi.repository import GLib, GObject, Gtk
 
 from gnomemusic import log
 from gnomemusic.albumartcache import AlbumArtCache, DefaultIcon, ArtSize
 from gnomemusic.grilo import grilo
-from gnomemusic.widgets.disclistboxwidget import DiscBox, DiscListBox
+from gnomemusic.widgets.disclistboxwidget import DiscBox
 import gnomemusic.utils as utils
 
 
@@ -45,7 +44,7 @@ class ArtistAlbumWidget(Gtk.Box):
     def __init__(self, media, player, model, header_bar,
                  selection_mode_allowed, size_group=None,
                  cover_size_group=None):
-        super().__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
+        super().__init__(orientation=Gtk.Orientation.HORIZONTAL)
 
         self._size_group = size_group
         self._cover_size_group = cover_size_group
@@ -53,7 +52,7 @@ class ArtistAlbumWidget(Gtk.Box):
         self._cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
             DefaultIcon.Type.loading,
-            ArtSize.medium)
+            ArtSize.MEDIUM)
 
         self._media = media
         self._player = player
@@ -97,7 +96,6 @@ class ArtistAlbumWidget(Gtk.Box):
         GLib.idle_add(self._update_album_art)
         grilo.populate_album_songs(self._media, self._add_item)
 
-
     def create_disc_box(self, disc_nr, disc_songs):
         disc_box = DiscBox(self._model)
         disc_box.set_songs(disc_songs)
@@ -163,7 +161,7 @@ class ArtistAlbumWidget(Gtk.Box):
 
     @log
     def _update_album_art(self):
-        self._cache.lookup(self._media, ArtSize.medium, self._get_album_cover,
+        self._cache.lookup(self._media, ArtSize.MEDIUM, self._get_album_cover,
                            None)
 
     @log
